    function ConvertTo-IPA {
        [CmdletBinding()]
        
        Param(
            [Parameter(Mandatory=$true)]
            [string]$language,
            
            [Parameter(Mandatory=$true)]
            [string]$word
        )
        
        $langfile = $language + ".ipa"
        $phonemetable = Import-CSV -Path $langfile -Delimiter '='
        ForEach($phoneme in $phonemetable) {
            $word = $word -replace $phoneme.ortho,$phoneme.ipa
        }
        return $word
    }

    function New-SSMLPhonemeTag {
        [CmdletBinding()]
        
        Param(
           [Parameter(Mandatory=$true)]
           [string]$language,
           
           [Parameter(Mandatory=$true)]
           [string]$word
        )
        
        $phonemetag = '<phoneme alphabet="ipa" ph="'
        $phonemetag += ConvertTo-IPA -word $word -language $language
        $phonemetag += '">' + $word + '</phoneme>'
        
        return $phonemetag
    }

    function New-PLSLexicon {
        [CmdletBinding()]
        
        param(
            [Parameter(Mandatory=$true)]
            [string]$language,
            
            [string]$wordfile,
            
            [string]$outfile
        )
        
        $lexicon = @()
        if ($wordfile -eq "") { $wordfile = $language + '.txt' }
        if ($outfile  -eq "") { $outfile  = $language + '.pls' }
        $wordlist = Get-Content $wordfile
        $lexicon += '<?xml version="1.0">'
        $lexicon += '<lexicon version="1.0" xmlns="http://www.w3.org/2005/01/pronunciation-lexicon" alphabet="ipa" xml:lang="en-US">'
        ForEach ($word in $wordlist) {
            $lexicon += '  <lexeme>'
            $lexicon += '    <grapheme>' + $word + '</grapheme>'
            $lexicon += '    <phoneme>' + (ConvertTo-IPA -word $word -language $language) + '</phoneme>'
            $lexicon += '  </lexeme>'
        }
        $lexicon += '</lexicon>'
        Set-Content -Encoding Unicode -Path $outfile -Value $lexicon
    }

